"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var remote_1 = require("./remote");
var constant_1 = require("./constant");
exports.makeHistory = function (commits, useGroup) {
    if (useGroup === void 0) { useGroup = false; }
    var history = '';
    var breakingChanges = [];
    if (useGroup) {
        history = groupHistory(commits).join('\n');
    }
    else {
        commits.forEach(function (commit) {
            extractLabels(commit);
            var hash = commit.hash, shortHash = commit.shortHash, subject = commit.subject, breakingChange = commit.breakingChange;
            if (breakingChange) {
                breakingChanges.push(breakingChange);
            }
            history += "- " + subject + " [`" + shortHash + "`](" + remote_1.getRemoteLink().commitLink + "/" + hash + ")\n";
        });
    }
    if (breakingChanges.length) {
        history += "### BREAKING CHANGES\n";
        breakingChanges.forEach(function (breakingChange) {
            history += "- " + breakingChange + "\n";
        });
    }
    return history;
};
var groupHistory = function (commits) {
    var groupCommits = [];
    var _loop_1 = function (group) {
        var targetGroup = commits.filter(function (commit) {
            return new RegExp(constant_1.GROUP_MAP[group], 'i').test(commit.type);
        });
        if (targetGroup.length) {
            groupCommits.push("### " + group + "\n");
            targetGroup.forEach(function (commit) {
                extractLabels(commit);
                var hash = commit.hash, shortHash = commit.shortHash, pureSubject = commit.pureSubject;
                groupCommits.push("- " + pureSubject + " [`" + shortHash + "`](" + remote_1.getRemoteLink().commitLink + "/" + hash + ")\n");
            });
        }
    };
    for (var group in constant_1.GROUP_MAP) {
        _loop_1(group);
    }
    return groupCommits;
};
var extractLabels = function (commit) {
    var body = commit.body;
    var reg = /(?:(?<![/\w-.])\w[\w-.]+\/\w[\w-.]+|\B)[#|\!][1-9]\d*\b/g;
    var labels = body.match(reg);
    if (labels !== null) {
        commit.subject += labels.join(' ');
        commit.pureSubject += labels.join(' ');
    }
};
